@@ -26,7 +26,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.2.1';
 
 
 # Preloaded methods go here.
@@ -39,14 +39,17 @@ __END__
 
 =head1 NAME
 
-GFX-Tools-Buffer - array code 
+GFX-Tools-Buffer - array and matrix code
 
 =head1 SYNOPSIS
 
-  use GFX-Tools-Buffer;
+  use GFX::Tools::Buffer;
 
 =head1 DESCRIPTION
 
+Contains several array and a fast matrix implmentation for use in any program
+you like these.
+
 =head2 EXPORT
 
 =head1 SEE ALSO
